pub fn s_barrier()🔬This is a nightly-only experimental API. (
stdarch_amdgpu #149988)Available on AMG GPU only.
Synchronize all wavefronts in a workgroup.
Each wavefronts in a workgroup waits at the barrier until all wavefronts in the workgroup arrive at a barrier.